@@ -5,7 +5,10 @@ Created on Wed Oct 31 16:23:13 2018
 
 @author: samschott
 """
+# system imports
 import sys
+import os
+import re
 import platform
 
 # external packages
@@ -42,6 +45,18 @@ thread_pool.setMaxThreadCount(10)
 # ======================================================================================
 
 
+def is_empty(dirname):
+    """Checks if a directory is empty."""
+
+    try:
+        with os.scandir(dirname) as sciter:
+            next(sciter)
+    except StopIteration:
+        return True
+
+    return False
+
+
 def elide_string(string, font=None, pixels=200, side="right"):
     """
     Elides a string to fit into the given width.
@@ -86,6 +101,29 @@ def get_scaled_font(scaling=1.0, bold=False, italic=False):
     return font
 
 
+url_regex = re.compile(
+    r"(?i)\b((?:https?://|www\d{0,3}[.]|[a-z0-9.\-]+[.][a-z]{2,4}/)(?:[^\s()<>]+|\(([^\s()<>]+|(\([^\s()<>]+\)))*\))+(?:\(([^\s()<>]+|(\([^\s()<>]+\)))*\)|[^\s`!()\[\]{};:'\".,<>?«»“”‘’]))"
+)
+
+
+def markup_urls(string):
+    """
+    Find any URLs in a string and wrap them in html a tags.
+
+    :param str string: String to parse.
+    :return: Marked-up string.
+    """
+
+    matches = url_regex.findall(string)
+
+    for match in matches:
+        url = "".join(match)
+        href = f'<a href="{url}">{url}</a>'
+        string = string.replace(url, href)
+
+    return string
+
+
 # noinspection PyArgumentList
 def icon_to_pixmap(icon, width, height=None):
     """Converts a given icon to a pixmap. Automatically adjusts to high-DPI scaling.
